@@ -2,14 +2,11 @@
 
 import logging
 import os
+from typing import Optional
 
-from evernote_backup.cli_app_util import (
-    ProgramTerminatedError,
-    get_auth_token,
-    get_storage,
-    get_sync_client,
-    raise_on_old_database_version,
-)
+from evernote_backup.cli_app_auth import get_auth_token, get_sync_client
+from evernote_backup.cli_app_storage import get_storage, raise_on_old_database_version
+from evernote_backup.cli_app_util import ProgramTerminatedError
 from evernote_backup.config import CURRENT_DB_VERSION
 from evernote_backup.note_exporter import NoteExporter, NothingToExportError
 from evernote_backup.note_storage import initialize_db
@@ -19,8 +16,14 @@ logger = logging.getLogger(__name__)
 
 
 def init_db(
-    database, auth_user, auth_password, auth_is_oauth, auth_token, force, backend
-):
+    database: str,
+    auth_user: Optional[str],
+    auth_password: Optional[str],
+    auth_is_oauth: bool,
+    auth_token: Optional[str],
+    force: bool,
+    backend: str,
+) -> None:
     if not auth_token:
         auth_token = get_auth_token(auth_user, auth_password, auth_is_oauth, backend)
 
@@ -49,7 +52,13 @@ def init_db(
     logger.info(f"Successfully initialized database for {new_user}!")
 
 
-def reauth(database, auth_user, auth_password, auth_is_oauth, auth_token):
+def reauth(
+    database: str,
+    auth_user: Optional[str],
+    auth_password: Optional[str],
+    auth_is_oauth: bool,
+    auth_token: Optional[str],
+) -> None:
     storage = get_storage(database)
 
     raise_on_old_database_version(storage)
@@ -74,7 +83,7 @@ def reauth(database, auth_user, auth_password, auth_is_oauth, auth_token):
     logger.info(f"Successfully refreshed auth token for {local_user}!")
 
 
-def sync(database):
+def sync(database: str) -> None:
     storage = get_storage(database)
 
     raise_on_old_database_version(storage)
@@ -97,7 +106,12 @@ def sync(database):
     logger.info("Synchronization completed!")
 
 
-def export(database, single_notes, include_trash, output_path):
+def export(
+    database: str,
+    single_notes: bool,
+    include_trash: bool,
+    output_path: str,
+) -> None:
     storage = get_storage(database)
 
     raise_on_old_database_version(storage)
