@@ -1,6 +1,7 @@
 import functools
 import inspect
 import platform
+from typing import Any, Optional, Union
 
 from evernote.edam.error.ttypes import (
     EDAMErrorCode,
@@ -8,6 +9,8 @@ from evernote.edam.error.ttypes import (
     EDAMUserException,
 )
 from evernote.edam.notestore import NoteStore
+from evernote.edam.userstore import UserStore
+from evernote.edam.userstore.ttypes import AuthenticationResult
 from thrift.protocol import TBinaryProtocol
 from thrift.transport import THttpClient
 
@@ -15,7 +18,7 @@ from evernote_backup.evernote_client_classes import ClientV2
 from evernote_backup.evernote_client_util import EvernoteAuthError, network_retry
 
 
-def raise_auth_error(exception):
+def raise_auth_error(exception: Union[EDAMSystemException, EDAMUserException]) -> None:
     messages = {
         EDAMErrorCode.BAD_DATA_FORMAT: {"authenticationToken": "Wrong token format!"},
         EDAMErrorCode.INVALID_AUTH: {
@@ -47,9 +50,8 @@ def raise_auth_error(exception):
     raise EvernoteAuthError(error)
 
 
-class EvernoteClient(object):
-    def __init__(self, token=None, backend=None):
-        self.token = token
+class EvernoteClientBase(object):
+    def __init__(self, backend: str) -> None:
         self.backend = backend
 
         backends = {
@@ -70,10 +72,18 @@ class EvernoteClient(object):
         if platform.node():
             self.device_description += " [{0}]".format(platform.node())
 
-        self._user = None
+    def _get_endpoint(self, path: str = "") -> str:
+        return f"https://{self.service_host}/{path}"
 
-    @network_retry
-    def verify_token(self):
+
+class EvernoteClient(EvernoteClientBase):
+    def __init__(self, backend: str, token: str) -> None:
+        super().__init__(backend=backend)
+
+        self.token = token
+        self._user: Optional[str] = None
+
+    def verify_token(self) -> None:
         try:
             self.user_store.getUser()
         except (EDAMUserException, EDAMSystemException) as e:
@@ -81,7 +91,7 @@ class EvernoteClient(object):
             raise
 
     @property
-    def user_store(self):
+    def user_store(self) -> "Store":
         user_store_uri = self._get_endpoint("edam/user")
         return Store(
             client_class=ClientV2,
@@ -91,8 +101,7 @@ class EvernoteClient(object):
         )
 
     @property
-    @network_retry
-    def note_store(self):
+    def note_store(self) -> "Store":
         note_store_uri = self.user_store.getNoteStoreUrl()
         return Store(
             client_class=NoteStore.Client,
@@ -102,31 +111,25 @@ class EvernoteClient(object):
         )
 
     @property
-    @network_retry
-    def user(self):
+    def user(self) -> str:
         if self._user is None:
             self._user = self.user_store.getUser().username
         return self._user
 
-    def _get_endpoint(self, path=""):
-        return f"https://{self.service_host}/{path}"
-
 
 class EvernoteClientAuth(EvernoteClient):
     def __init__(
         self,
-        token=None,
-        backend=None,
-        consumer_key=None,
-        consumer_secret=None,
+        backend: str,
+        consumer_key: str,
+        consumer_secret: str,
     ):
-        super().__init__(token=token, backend=backend)
+        super().__init__(backend=backend, token="")  # noqa: S106
 
         self.consumer_key = consumer_key
         self.consumer_secret = consumer_secret
 
-    @network_retry
-    def login(self, username, password):
+    def login(self, username: str, password: str) -> AuthenticationResult:
         try:
             return self.user_store.authenticateLongSessionV2(
                 username=username,
@@ -143,8 +146,7 @@ class EvernoteClientAuth(EvernoteClient):
             raise_auth_error(e)
             raise
 
-    @network_retry
-    def two_factor_auth(self, auth_token, ota_code):
+    def two_factor_auth(self, auth_token: str, ota_code: str) -> AuthenticationResult:
         try:
             return self.user_store.completeTwoFactorAuthentication(
                 authenticationToken=auth_token,
@@ -157,37 +159,50 @@ class EvernoteClientAuth(EvernoteClient):
             raise
 
 
-class Store(object):  # pragma: no cover
-    def __init__(self, client_class, store_url, user_agent, token=None):
+class Store(object):
+    def __init__(
+        self,
+        client_class: Union[UserStore.Client, NoteStore.Client],
+        store_url: str,
+        user_agent: str,
+        token: Optional[str] = None,
+    ):
         self.token = token
         self.user_agent = user_agent
 
         self._client = self._get_thrift_client(client_class, store_url)
 
-    def __getattr__(self, name):
-        def delegate_method(*args, **kwargs):  # noqa: WPS430
-            targetMethod = getattr(self._client, name, None)
-            if targetMethod is None:
-                return object.__getattribute__(self, name)(  # noqa: WPS609
-                    *args,
-                    **kwargs,
-                )
+    def __getattr__(self, name: str) -> Any:
+        target_method = getattr(self._client, name)
 
-            org_args = inspect.getfullargspec(targetMethod).args
+        if not callable(target_method):
+            return target_method
+
+        def wrapper(*args: Any, **kwargs: Any) -> Any:
+            target_method_retry = network_retry(target_method)
+
+            org_args = inspect.getfullargspec(target_method).args
             if len(org_args) == len(args) + 1:
-                return targetMethod(*args, **kwargs)
+                return target_method_retry(*args, **kwargs)
             elif self.token and "authenticationToken" in org_args:
                 skip_args = ["self", "authenticationToken"]
                 arg_names = [i for i in org_args if i not in skip_args]
-                return functools.partial(targetMethod, authenticationToken=self.token)(
+                return functools.partial(
+                    target_method_retry,
+                    authenticationToken=self.token,
+                )(
                     **dict(list(zip(arg_names, args))),
                 )
 
-            return targetMethod(*args, **kwargs)
+            return target_method_retry(*args, **kwargs)
 
-        return delegate_method
+        return wrapper
 
-    def _get_thrift_client(self, client_class, url):
+    def _get_thrift_client(
+        self,
+        client_class: Union[UserStore.Client, NoteStore.Client],
+        url: str,
+    ) -> Union[UserStore.Client, NoteStore.Client]:
         http_client = THttpClient.THttpClient(url)
         http_client.setCustomHeaders(
             {
