@@ -4,7 +4,7 @@ import lzma
 import os
 import pickle
 import sqlite3
-from typing import Iterator, List, Tuple, Union
+from typing import Iterable, Iterator, Tuple, Union
 
 from evernote.edam.type.ttypes import Note, Notebook
 
@@ -27,7 +27,9 @@ DB_SCHEMA = """CREATE TABLE IF NOT EXISTS notebooks(
                         value TEXT
                     );
                     CREATE INDEX IF NOT EXISTS idx_notes
-                     ON notes(notebook_guid, is_active);"""
+                     ON notes(notebook_guid, is_active);
+                    CREATE INDEX IF NOT EXISTS idx_notes_title
+                     ON notes(title COLLATE NOCASE);"""
 
 
 class DatabaseResyncRequiredError(Exception):
@@ -73,28 +75,42 @@ class SqliteStorage(object):
     def notebooks(self) -> "NoteBookStorage":
         return NoteBookStorage(self.db)
 
-    def check_version(self):
+    def check_version(self) -> None:
         try:
             db_version = int(self.config.get_config_value("DB_VERSION"))
         except KeyError:
             db_version = 0
 
-        if db_version == 0:
-            with self.db as con:
-                con.execute("DROP TABLE notebooks;")
-                con.execute("DROP TABLE notes;")
-
-                con.executescript(DB_SCHEMA)
-
         if db_version != CURRENT_DB_VERSION:
-            self.config.set_config_value("DB_VERSION", str(CURRENT_DB_VERSION))
-            self.config.set_config_value("USN", "0")
+            self.upgrade_db(db_version)
 
+    def upgrade_db(self, db_version: int) -> None:
+        need_resync = False
+
+        if db_version == 0:
+            need_resync = True
+            with self.db as con1:
+                con1.execute("DROP TABLE notebooks;")
+                con1.execute("DROP TABLE notes;")
+
+                con1.executescript(DB_SCHEMA)
+
+        if db_version < 3:
+            with self.db as con2:
+                con2.execute(
+                    "CREATE INDEX IF NOT EXISTS idx_notes_title"
+                    " ON notes(title COLLATE NOCASE);"
+                )
+
+        self.config.set_config_value("DB_VERSION", str(CURRENT_DB_VERSION))
+
+        if need_resync:
+            self.config.set_config_value("USN", "0")
             raise DatabaseResyncRequiredError
 
 
 class NoteBookStorage(SqliteStorage):
-    def add_notebooks(self, notebooks: List[Notebook]) -> None:
+    def add_notebooks(self, notebooks: Iterable[Notebook]) -> None:
         with self.db as con:
             con.executemany(
                 "replace into notebooks(guid, name, stack)" " values (?, ?, ?)",
@@ -126,13 +142,13 @@ class NoteBookStorage(SqliteStorage):
 
             return int(cur.fetchone()[0])
 
-    def expunge_notebooks(self, guids: List[str]) -> None:
+    def expunge_notebooks(self, guids: Iterable[str]) -> None:
         with self.db as con:
             con.executemany("delete from notebooks where guid=?", ((g,) for g in guids))
 
 
 class NoteStorage(SqliteStorage):
-    def add_notes_for_sync(self, notes: List[Note]) -> None:
+    def add_notes_for_sync(self, notes: Iterable[Note]) -> None:
         with self.db as con:
             con.executemany(
                 "replace into notes(guid, title) values (?, ?)",
@@ -160,7 +176,7 @@ class NoteStorage(SqliteStorage):
             cur = con.execute(
                 "select raw_note"
                 " from notes where notebook_guid=? and is_active=1"
-                " order by title",
+                " order by title COLLATE NOCASE",
                 (notebook_guid,),
             )
 
@@ -169,7 +185,9 @@ class NoteStorage(SqliteStorage):
     def iter_notes_trash(self) -> Iterator[Note]:
         with self.db as con:
             cur = con.execute(
-                "select raw_note" " from notes where is_active=0" " order by title",
+                "select raw_note"
+                " from notes where is_active=0"
+                " order by title COLLATE NOCASE",
             )
 
             yield from (pickle.loads(lzma.decompress(row["raw_note"])) for row in cur)
@@ -182,11 +200,11 @@ class NoteStorage(SqliteStorage):
 
             return tuple(notes)
 
-    def expunge_notes(self, guids: str) -> None:
+    def expunge_notes(self, guids: Iterable[str]) -> None:
         with self.db as con:
             con.executemany("delete from notes where guid=?", ((g,) for g in guids))
 
-    def get_notes_count(self, is_active: bool = True):
+    def get_notes_count(self, is_active: bool = True) -> int:
         with self.db as con:
             cur = con.execute(
                 "select COUNT(guid) from notes where is_active=?", (is_active,)
@@ -211,4 +229,4 @@ class ConfigStorage(SqliteStorage):
             if not res:
                 raise KeyError(f"Config ID {name} not found in database!")
 
-            return res[0]
+            return str(res[0])
